@@ -1,5 +1,5 @@
 # Verilog::Language.pm -- Verilog language keywords, etc
-# $Id: Language.pm,v 1.12 2001/02/13 17:41:05 wsnyder Exp $
+# $Id: Language.pm,v 1.25 2001/10/26 17:34:18 wsnyder Exp $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -99,7 +99,13 @@ will get intuitive results.
 =head1 DISTRIBUTION
 
 The latest version is available from
-C<http://www.ultranet.com/~wsnyder/verilog-perl>.
+C<http://veripool.com/verilog-perl>.
+
+=head1 SEE ALSO
+
+C<Verilog::Parser>, 
+C<Verilog::ParseSig>, 
+C<Verilog::Getopt>, 
 
 =head1 AUTHORS
 
@@ -113,40 +119,51 @@ require 5.000;
 require Exporter;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION %Keyword %Compdirect);
 
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.9';
+$VERSION = '2.000';
 
 ######################################################################
 #### Internal Variables
 
-my $kwd;
-foreach $kwd ("always", "and", "assign", "begin",
-	      "buf", "bufif0", "bufif1", "case", "casex", "casez", "cmos",
-	      "default", "defparam", "else", "end", "endcase",
-	      "endfunction", "endmodule", "endprimitive", "endspecify",
-	      "endtable", "endtask", "event", "for", "force", "forever",
-	      "fork", "function", "if", "initial", "inout", "input",
-	      "integer", "join", "macromodule", "makefile", "module",
-	      "nand", "negedge", "nmos", "nor", "not", "notif0", "notif1",
-	      "or", "output", "parameter", "pmos", "posedge", "primitive",
-	      "pulldown", "pullup", "rcmos", "real", "realtime", "reg",
-	      "repeat", "rnmos", "rpmos", "rtran", "rtranif0", "rtranif1",
-	      "signed", "specify", "supply", "supply0", "supply1", "table",
-	      "task", "time", "tran", "tranif0", "tranif1", "tri", "tri0",
-	      "tri1", "triand", "trior", "trireg", "vectored", "wait",
-	      "wand", "while", "wire", "wor", "xnor", "xor") {
-    $Verilog::Language::keyword{$kwd} = 1;
+foreach my $kwd (qw(
+		    always and assign begin buf bufif0 bufif1 case
+		    casex casez cmos deassign default defparam
+		    disable else end endcase endfunction endmodule
+		    endprimitive endspecify endtable endtask event
+		    extern for force forever fork function highz0
+		    highz1 if initial inout input integer join large
+		    macromodule makefile medium module nand negedge
+		    nmos nor not notif0 notif1 or output parameter
+		    pmos posedge primitive pull0 pull1 pulldown
+		    pullup rcmos real realtime reg release repeat
+		    rnmos rpmos rtran rtranif0 rtranif1 scalared
+		    signed small specify strong0 strong1 supply
+		    supply0 supply1 table task time tran tranif0
+		    tranif1 tri tri0 tri1 triand trior trireg
+		    vectored wait wand weak0 weak1 while wire wor
+		    xnor xor
+
+		    automatic cell config design endconfig endgenerate
+		    generate genvar instance liblist localparam
+		    noshowcancelled pulsestyle_ondetect pulsestyle_onevent
+		    showcancelled signed use
+		    )) {
+    $Keyword{$kwd} = 1;
 }
-foreach $kwd ("`celldefine", "`default_nettype", "`define", "`else",
-	      "`endcelldefine", "`endif", "`ifdef", "`include",
-	      "`nounconnected_drive", "`resetall", "`timescale",
-	      "`unconnected_drive", "`undef") {
-    $Verilog::Language::keyword{$kwd} = 1;
-    $Verilog::Language::compdirect{$kwd} = 1;
+foreach my $kwd ("`celldefine", "`default_nettype", "`define", "`else",
+		 "`endcelldefine", "`endif", "`ifdef", "`include",
+		 "`nounconnected_drive", "`resetall", "`timescale",
+		 "`unconnected_drive", "`undef",
+		 # Verilog 2001
+		 "`default_nettype", "`elsif", "`undef", "`ifndef",
+		 "`file", "`line",
+		 ) {
+    $Keyword{$kwd} = 1;
+    $Compdirect{$kwd} = 1;
 }
 
 ######################################################################
@@ -154,12 +171,12 @@ foreach $kwd ("`celldefine", "`default_nettype", "`define", "`else",
 
 sub is_keyword {
     my $symbol = shift;
-    return ($Verilog::Language::keyword {$symbol});
+    return ($Keyword {$symbol});
 }
 
 sub is_compdirect {
     my $symbol = shift;
-    return ($Verilog::Language::compdirect {$symbol});
+    return ($Compdirect {$symbol});
 }
 
 ######################################################################
@@ -306,19 +323,6 @@ sub split_bus {
     }
 }
 
-#sub split_bus_test {
-#    my $x;
-#    $x = "ff[5:1:2,4]e";
-#    foreach (Verilog::Language::split_bus ($x)) {
-#	 print "MM $x .. $_\n";
-#    }
-#    $x = "ff[3:1]  bar [4'ha:3] end";
-#    foreach (Verilog::Language::split_bus ($x)) {
-#	 print "MM $x .. $_\n";
-#    }
-#    die;
-#}
-
 sub split_bus_nocomma {
     # Faster version of split_bus
     my $bus = shift;
