@@ -1,5 +1,5 @@
 # Verilog::Parse.pm -- Verilog preprocessing
-# $Id: Parse.pm,v 1.7 2001/02/13 15:11:15 wsnyder Exp $
+# $Id: Parse.pm,v 1.13 2001/10/26 17:34:18 wsnyder Exp $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -130,7 +130,7 @@ that aren\'t covered.
 =head1 DISTRIBUTION
 
 The latest version is available from
-C<http://www.ultranet.com/~wsnyder/verilog-perl>.
+C<http://veripool.com/verilog-perl>.
 
 =head1 AUTHORS
 
@@ -158,7 +158,7 @@ use Verilog::Language;
 # Other configurable settings.
 $Verilog::Parse::debug = 0;		# for debugging
 
-$VERSION = '1.4';
+$VERSION = '2.000';
 
 #######################################################################
 
