@@ -1,5 +1,5 @@
 # Verilog::Parser.pm -- Verilog parsing
-# $Id: Parser.pm,v 1.11 2001/02/13 17:41:05 wsnyder Exp $
+# $Id: Parser.pm,v 1.23 2001/10/29 18:26:46 wsnyder Exp $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -67,7 +67,7 @@ callback.  (For example comments, if there is no comment callback.)  This
 is useful for recording the entire contents of the input, for
 preprocessors, pretty-printers, and such.
 
-=item $parser->line ($set)
+=item $parser->lineno ($set)
 
 Return (if $set is undefined) or set current line number.
 
@@ -179,7 +179,7 @@ boundary.  It should be changed to allow arbitrary chunks.
 =head1 DISTRIBUTION
 
 The latest version is available from
-C<http://www.ultranet.com/~wsnyder/verilog-perl>.
+C<http://veripool.com/verilog-perl>.
 
 =head1 AUTHORS
 
@@ -206,7 +206,7 @@ use Verilog::Language;
 # Other configurable settings.
 $Debug = 0;		# for debugging
 
-$VERSION = '1.9';
+$VERSION = '2.000';
 
 #######################################################################
 
@@ -248,6 +248,7 @@ sub unreadback {
     }
 }
 
+sub lineno { return line(@_); }
 sub line {
     # Return or set line number
     my $self = shift;	# Parser
@@ -266,6 +267,18 @@ sub filename {
     return $self->{filename};
 }
 
+sub reset {
+    # Reset internal parse states
+    my $self = shift;	# Parser
+
+    $self->{unreadback} = "";
+    $self->{line} = 1;
+    $self->{filename} = "UNKNOWN";
+    $self->{incomment} = 0;
+    $self->{inquote} = 0;
+    $self->{preprocess} = 0;
+}
+
 #######################################################################
 
 sub comment {
@@ -319,24 +332,27 @@ sub parse {
     my $self = shift;
     my $text = shift;
 
+    # All state must be changed before the callback.  This allows the callback
+    # to call the parser recursively (such as for `include files).
+
     while ($text ne "") {
 	print "Lnc $text" if ($Debug);
-	if ($text =~ s/^\n//) {
+	if ($text =~ s/^(\s*\n)//) {
 	    $self->{line}++;
 	    if ($self->{incomment}
 		|| $self->{inquote}) {
-		$self->{token_string} .= "\n";
+		$self->{token_string} .= $1;
 	    } else {
-		$self->{unreadback} .= "\n";
+		$self->{unreadback} .= $1;
 	    }
 	}
 	elsif ($self->{incomment}) {
 	    if ($text =~ s/^( [^\n]*? \*\/ )//x) {
 		$self->{token_string} .= $1;
+		$self->{incomment} = 0;
 		my $token = $self->{token_string};
 		print "GotaCOMMENT $token\n"    if ($Debug);
 		$self->comment ($token);
-		$self->{incomment} = 0;
 	    }
 	    elsif ($text =~ s/^([^\n]*)// ) {
 		$self->{token_string} .= $1;
@@ -347,10 +363,10 @@ sub parse {
 	    if ($text =~ s/^([^\n]*?\")//) {
 		$self->{token_string} .= $1;
 		if ($self->{token_string} !~ /\\\"$/) {	# \"
+		    $self->{inquote} = 0;
 		    my $token = $self->{token_string};
 		    print "GotaSTRING $token\n"    if ($Debug);
 		    $self->string ($token);
-		    $self->{inquote} = 0;
 		}
 	    } elsif ($text =~ s/^([^\n]*)//) {
 		$self->{token_string} .= $1;
@@ -362,7 +378,7 @@ sub parse {
 	    if ($text =~ s/^(\s+)//) {
 		$self->{unreadback} .= $1;
 	    }
-	    if ($text =~ /^\\n/) {
+	    if ($text =~ /^\n/) {
 		#Fall though
 	    }
 	    elsif ($text =~ s/^\"//) {
@@ -391,7 +407,8 @@ sub parse {
 		print "GotaCOMMENT $token\n"    if ($Debug);
 		$self->comment ($token);
 	    }
-	    elsif (($text =~ s/^(&& | \|\| | == | != | <= | >= | << | >> )//x)
+	    elsif (($text =~ s/^(&& | \|\| | == | != | <= | >=
+				 | << | >> | \+: | \-: | \*\* )//x)
 		   || ($text =~ s/^( [][:;@\(\),.%!=<>?|&{}~^+---\/*\#] )//x)) {  #]
 		my $token = $1;
 		print "GotaOPERATOR $token\n"    if ($Debug);
@@ -423,7 +440,9 @@ sub parse_file {
 
     my $fh = new FileHandle;
     $fh->open($filename) or croak "%Error: $! $filename";
+    $self->reset();
     $self->filename($filename);
+    $self->line(1);
     my $line;
     while ($line = $fh->getline() ) {
 	$self->parse ($line);
