@@ -1,5 +1,5 @@
 # Verilog::SigParser.pm -- Verilog signal parsing
-# $Id: SigParser.pm,v 1.8 2001/02/13 15:11:15 wsnyder Exp $
+# $Id: SigParser.pm,v 1.15 2001/10/29 18:26:46 wsnyder Exp $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -32,8 +32,8 @@ Verilog::SigParser - Signal Parsing for Verilog language files
   my $parser = new Verilog::SigParser;
   $string = $parser->unreadback ();
   $line   = $parser->line ();
-  $parser->parse ($text)
-  $parser->parse_file ($filename)
+  $parser->parse ($text);
+  $parser->parse_file ($filename);
 
 =head1 DESCRIPTION
 
@@ -91,7 +91,7 @@ that aren\'t covered.
 =head1 DISTRIBUTION
 
 The latest version is available from
-C<http://www.ultranet.com/~wsnyder/verilog-perl>.
+C<http://veripool.com/verilog-perl>.
 
 =head1 AUTHORS
 
@@ -119,7 +119,7 @@ use Verilog::Parser;
 # Other configurable settings.
 $Debug = 0;		# for debugging
 
-$VERSION = '1.5';
+$VERSION = '2.000';
 
 #######################################################################
 
@@ -209,6 +209,30 @@ sub ppinclude {
 ######################################################################
 # Overrides of Verilog::Parser routines
 
+sub reset {
+    # Verilog::Parser calls when a new file is parsed
+    my $self = shift;	# Parser invoked
+    $self->SUPER::reset();
+
+    $self->{last_operator} = "";
+    $self->{last_keyword} = "";
+    $self->{last_module} = undef;
+    $self->{last_function} = undef;
+    $self->{last_task} = undef;
+    $self->{last_vectors} = "";
+    $self->{last_param} = "";
+    $self->{is_inst_ok} = 1;
+    $self->{is_pin_ok} = 0;
+    $self->{is_signal_ok} = 1;
+    $self->{in_preproc_line} = -1;
+    $self->{in_vector} = 0;
+    $self->{in_param_assign} = 0;
+    $self->{possibly_in_param_assign} = 0;
+    $self->{pin_name} = undef;
+
+    @{$self->{last_symbols}} = ();
+}
+
 sub keyword {
     # Verilog::Parse calls when keyword occurs
     my $self = shift;	# Parser invoked
@@ -242,6 +266,13 @@ sub keyword {
 	$self->{is_pin_ok} = 0;
 	$self->{got_preproc} = 0;
     }
+    elsif ($token eq "endtask") {
+	$self->{last_task} = undef;
+    } elsif ($token eq "endmodule") {
+	$self->{last_module} = undef;
+    } elsif ($token eq "endfunction") {
+	$self->{last_function} = undef;
+    }
 }
 
 sub symbol {
@@ -347,13 +378,6 @@ sub operator {
 		    print "Gota$lkw $mod\n"    if ($Debug);
 		    $self->function ($lkw, $mod);
 		}
-		elsif ($lkw eq "endtask") {
-		    $self->{last_task} = undef;
-		} elsif ($lkw eq "endmodule") {
-		    $self->{last_module} = undef;
-		} elsif ($lkw eq "endfunction") {
-		    $self->{last_function} = undef;
-		}
 		elsif ((($lkw eq "input")
 			|| ($lkw eq "output")
 			|| ($lkw eq "inout")
